import _extends from "@babel/runtime/helpers/esm/extends";
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import AtomIcon, { ATOM_ICON_COLORS, ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import ActionButton from './ActionButton';
/**
 * Base class for the component
 */

var BASE_CLASS = 'react-AtomActionButton';
/**
 * Available colors for the Action Button
 */

var COLORS = {
  PRIMARY: 'primary',
  ACCENT: 'accent',
  NEUTRAL: 'neutral'
};
/**
 * Available modifiers for the Action Button
 */

var MODIFIERS = {
  ACTIVE_FOCUSED: 'active',
  DISABLED: 'disabled',
  LINK: 'link'
};
/**
 * Available sizes for the Action Button
 */

var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};
/**
 * Available styles for the Action Button
 */

var STYLES = {
  FILLED_NEGATIVE: 'filledNegative',
  FILLED_POSITIVE: 'filledPositive',
  OUTLINE: 'outline',
  FLAT: 'flat'
};

var createClasses = function createClasses(array, sufix) {
  if (sufix === void 0) {
    sufix = '';
  }

  return array.reduce(function (res, key) {
    var _extends2;

    return _extends(_extends({}, res), {}, (_extends2 = {}, _extends2[key] = BASE_CLASS + "--" + key + sufix, _extends2));
  }, {});
};

var CLASSES = createClasses([].concat(Object.values(SIZES), Object.values(STYLES), Object.values(MODIFIERS)));
var COLOR_CLASSES = createClasses([].concat(Object.values(COLORS)), 'Color');

var AtomActionButton = function AtomActionButton(_ref) {
  var children = _ref.children,
      className = _ref.className,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? COLORS.PRIMARY : _ref$color,
      disabled = _ref.disabled,
      focused = _ref.focused,
      href = _ref.href,
      icon = _ref.icon,
      isButton = _ref.isButton,
      isSubmit = _ref.isSubmit,
      link = _ref.link,
      linkFactory = _ref.linkFactory,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.MEDIUM : _ref$size,
      _ref$style = _ref.style,
      style = _ref$style === void 0 ? STYLES.FILLED_NEGATIVE : _ref$style,
      target = _ref.target,
      title = _ref.title;
  var classNames = cx(BASE_CLASS, COLOR_CLASSES[color], CLASSES[style], CLASSES[size], focused && CLASSES[MODIFIERS.ACTIVE_FOCUSED], disabled && CLASSES[MODIFIERS.DISABLED], link && CLASSES[MODIFIERS.LINK], className);
  var buttonProps = {
    href: href,
    isButton: isButton,
    isSubmit: isSubmit,
    link: link,
    linkFactory: linkFactory,
    target: target,
    title: title
  };
  return /*#__PURE__*/React.createElement(ActionButton, Object.assign({}, buttonProps, {
    className: classNames
  }), /*#__PURE__*/React.createElement("div", {
    className: BASE_CLASS + "-icon"
  }, /*#__PURE__*/React.createElement(AtomIcon, {
    size: ATOM_ICON_SIZES.medium,
    color: ATOM_ICON_COLORS.currentColor
  }, icon)), /*#__PURE__*/React.createElement("div", {
    className: BASE_CLASS + "-text"
  }, children));
};

AtomActionButton.displayName = 'AtomActionButton';
export default AtomActionButton;
export { COLORS as atomActionButtonColors };
export { SIZES as atomActionButtonSizes };
export { STYLES as atomActionButtonStyles };